sirocco: Compute topologically certified root continuation of bivariate polynomials
===================================================================================

Description
-----------

sirocco is a library to compute topologically certified root
continuation of bivariate polynomials.

License
-------

GPLv3+


Upstream Contact
----------------

Miguel Marco (mmarco@unizar.es)

https://github.com/miguelmarco/SIROCCO2
